@@ -1,4 +1,6 @@
-from dateutil import parser
+from datetime import date, datetime
+from typing import Optional, Union
+
 from django.conf import settings
 from edc_utils import convert_php_dateformat
 
@@ -6,12 +8,17 @@ from edc_form_validators.base_form_validator import INVALID_ERROR, BaseFormValid
 
 
 class DateValidator(BaseFormValidator):
-    def _date_is(self, op, field=None, reference_field=None, msg=None):
+    def _date_is(
+        self,
+        op,
+        field: Optional[str] = None,
+        reference_field: Optional[str] = None,
+        msg: Optional[str] = None,
+    ):
         operators = ["<", ">", "="]
         if op not in operators:
             raise TypeError(f"Invalid operator. Expected on of {operators}.")
         if self.cleaned_data.get(field) and self.cleaned_data.get(reference_field):
-            value = None
             try:
                 date_value = self.cleaned_data.get(field).date()
             except AttributeError:
@@ -20,15 +27,23 @@ class DateValidator(BaseFormValidator):
                 reference_value = self.cleaned_data.get(reference_field).date()
             except AttributeError:
                 reference_value = self.cleaned_data.get(reference_field)
-            if op == "<":
-                value = reference_value < date_value
-            elif op == ">":
-                value = reference_value > date_value
-            elif op == "=":
-                value = reference_value == date_value
+            value = self.compare_to_reference_value(op, reference_value, date_value)
             if value:
                 self.raise_validation_error({field: msg}, INVALID_ERROR)
 
+    @staticmethod
+    def compare_to_reference_value(
+        op: str, reference_value: Union[date, datetime], date_value: date
+    ) -> Optional[bool]:
+        value = None
+        if op == "<":
+            value = reference_value < date_value
+        elif op == ">":
+            value = reference_value > date_value
+        elif op == "=":
+            value = reference_value == date_value
+        return value
+
     def date_is_future(self, field=None, reference_field=None, msg=None, extra_msg=None):
         """Raises if date/datetime field is future relative
         to reference_field.
